@@ -13,13 +13,13 @@ from xml.dom import minidom
 try:
     conn = libvirt.openReadOnly(None)
 except libvirt.libvirtError:
-    print 'Failed to connect to the hypervisor'
+    print('Failed to connect to the hypervisor')
     sys.exit(1)
 
 try:
     capsXML = conn.getCapabilities()
 except libvirt.libvirtError:
-    print 'Failed to request capabilities'
+    print('Failed to request capabilities')
     sys.exit(1)
 
 caps = minidom.parseString(capsXML)
@@ -38,8 +38,8 @@ siblingsIds = [ proc.getAttribute('siblings')
                 for proc in cells.getElementsByTagName('cpu')
                 if proc.getAttribute('siblings') not in siblingsIds ]
 
-print "Host topology"
-print "NUMA nodes:", cells.getAttribute('num')
-print "   Sockets:", len(set(socketIds))
-print "     Cores:", len(set(siblingsIds))
-print "   Threads:", total_cpus
+print("Host topology")
+print("NUMA nodes:", cells.getAttribute('num'))
+print("   Sockets:", len(set(socketIds)))
+print("     Cores:", len(set(siblingsIds)))
+print("   Threads:", total_cpus)
